function [out_cells] = CollapseCells(in_cells)
%COLLAPSECELLS Collapse (possibly nested) cell arrays to a single Kx1 cell array
%   [OUT_CELLS] = COLLAPSECELLS(IN_CELLS) takes as input a (nested) cell
%   array IN_CELLS and produces a Kx1 cell array with the same contents. 
%
%   This function is especially useful for collapsing the output of regexp
%   when using the 'tokens' parameter.

  out_cells = cat(1, in_cells{:});
  
  % If we have a nested cell array, collapse it
  if (iscell(out_cells{1}))
    out_cells = cellfun(@cell2mat, out_cells, 'UniformOutput', false);
  end

end

