function [] = Preprocess_1_RemovePartialHITs(base_dir)
%Preprocess_1_RemovePartialHITs Only keep submitted results
%   Since the mturk user study saves results for all images, including those 
%   that were not submitted by a turker (i.e. the turker gave up), we need to 
%   purge the database. This function only copies image files that were actually 
%   submitted.

  raw_dir = [base_dir 'raw/'];
  processed_raw_dir = [base_dir 'processed1/'];

  % We iterate all assignment info files
  filenames = dir([raw_dir 'as_*.txt']);
  filenames = {filenames.name};
  
  assignment_id_regexp = 'as_(.{30})\.txt';
  
  % keep_list will hold all assignment ids we would like to keep
  keep_list = [];
  
  % We add assignment ids to keep_list if the corresponding file contains
  % the 'Image DONE: ' string
  for ii = 1:numel(filenames)
    % extract assignment id from file name
    current_file = filenames{ii};
    current_assignment_id = regexp(current_file, assignment_id_regexp, 'tokens');
    if isempty(current_assignment_id)
      continue;
    end
    % Assignment id is the first (and only) token
    current_assignment_id = current_assignment_id{1};
    
    % Read info file
    contents = fileread([raw_dir current_file]);
    
    if ~isempty(strfind(contents, 'Image DONE: '))
      keep_list = [keep_list ; current_assignment_id];
    end
  end
  
  % Iterate all .png files, copying those on the keep list
  filenames = dir([raw_dir '*.png']);
  filenames = {filenames.name};
  
  assignment_id_regexp = '(.{30})__.*\.png';

  for ii = 1:numel(filenames)
    % extract assignment id from file name
    current_file = filenames{ii};
    current_assignment_id = regexp(current_file, assignment_id_regexp, 'tokens');
    current_assignment_id = current_assignment_id{1};
    
    % if assignment id in keep list, copy the file to the processed_raw directory
    if any(strcmp(keep_list, current_assignment_id))
      src_filename = [raw_dir current_file];
      fprintf('Copying %s to %s\n', src_filename, processed_raw_dir);
      copyfile(src_filename, processed_raw_dir);
    end
  end
end

